@@ -83,6 +83,7 @@ struct _GeditAppPrivate
 	GtkPrintSettings  *print_settings;
 
 	GObject           *settings;
+	GSettings         *ui_settings;
 	GSettings         *window_settings;
 
 	PeasExtensionSet  *extensions;
@@ -96,6 +97,7 @@ static gboolean new_window = FALSE;
 static gboolean new_document = FALSE;
 static gchar *geometry = NULL;
 static gboolean wait = FALSE;
+static gboolean gapplication_service = FALSE;
 static gboolean standalone = FALSE;
 static gchar **remaining_args = NULL;
 static const GeditEncoding *encoding = NULL;
@@ -158,6 +160,14 @@ static const GOptionEntry options[] =
 		N_("GEOMETRY")
 	},
 
+	/* GApplication service mode */
+	{
+		"gapplication-service", '\0', 0, G_OPTION_ARG_NONE,
+		&gapplication_service,
+		N_("Enter GApplication service mode"),
+		NULL
+	},
+
 	/* Wait for closing documents */
 	{
 		"wait", 'w', 0, G_OPTION_ARG_NONE,
@@ -192,6 +202,7 @@ gedit_app_dispose (GObject *object)
 {
 	GeditApp *app = GEDIT_APP (object);
 
+	g_clear_object (&app->priv->ui_settings);
 	g_clear_object (&app->priv->window_settings);
 	g_clear_object (&app->priv->settings);
 
@@ -373,11 +384,11 @@ quit_activated (GSimpleAction *action,
                 GVariant      *parameter,
                 gpointer       user_data)
 {
-	_gedit_cmd_file_quit (NULL, NULL);
+	_gedit_cmd_file_quit (NULL, NULL, NULL);
 }
 
 static GActionEntry app_entries[] = {
-	{ "new_window", new_window_activated, NULL, NULL, NULL },
+	{ "new-window", new_window_activated, NULL, NULL, NULL },
 	{ "preferences", preferences_activated, NULL, NULL, NULL },
 	{ "help", help_activated, NULL, NULL, NULL },
 	{ "about", about_activated, NULL, NULL, NULL },
@@ -413,6 +424,9 @@ gedit_app_startup (GApplication *application)
 	const gchar *cache_dir;
 	gchar *metadata_filename;
 #endif
+	GError *error = NULL;
+	GFile *css_file;
+	GtkCssProvider *provider;
 
 	G_APPLICATION_CLASS (gedit_app_parent_class)->startup (application);
 
@@ -452,21 +466,21 @@ gedit_app_startup (GApplication *application)
 
 	/* Load settings */
 	app->priv->settings = gedit_settings_new ();
+	app->priv->ui_settings = g_settings_new ("org.gnome.gedit.preferences.ui");
 	app->priv->window_settings = g_settings_new ("org.gnome.gedit.state.window");
 
 	/* initial lockdown state */
 	app->priv->lockdown = gedit_settings_get_lockdown (GEDIT_SETTINGS (app->priv->settings));
 
+	g_action_map_add_action_entries (G_ACTION_MAP (app),
+	                                 app_entries,
+	                                 G_N_ELEMENTS (app_entries),
+	                                 app);
+
 	/* app menu */
 	if (_gedit_app_has_app_menu (app))
 	{
 		GtkBuilder *builder;
-		GError *error = NULL;
-
-		g_action_map_add_action_entries (G_ACTION_MAP (app),
-			                         app_entries,
-			                         G_N_ELEMENTS (app_entries),
-			                         app);
 
 		builder = gtk_builder_new ();
 		if (!gtk_builder_add_from_resource (builder,
@@ -488,6 +502,77 @@ gedit_app_startup (GApplication *application)
 		g_object_unref (builder);
 	}
 
+	/* Accelerators */
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>Q", "app.quit", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "F1", "app.help", NULL);
+
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>O", "win.open", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>S", "win.save", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift>S", "win.save_as", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift>L", "win.save_all", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>T", "win.new_tab", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>W", "win.close", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift>W", "win.close_all", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>P", "win.print", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>F", "win.find", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>G", "win.find_next", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift>G", "win.find_prev", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>H", "win.replace", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift>K", "win.clear_highlight", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>I", "win.goto_line", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "F9", "win.side_panel", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary>F9", "win.bottom_panel", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "F11", "win.fullscreen", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Alt>N", "win.new_tab_group", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift><Alt>Page_Up",
+	                                 "win.previous_tab_group", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Shift><Alt>Page_Down",
+	                                 "win.next_tab_group", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Alt>Page_Up",
+	                                 "win.previous_document", NULL);
+	gtk_application_add_accelerator (GTK_APPLICATION (application),
+	                                 "<Primary><Alt>Page_Down",
+	                                 "win.next_document", NULL);
+
+	/* Load custom css */
+	error = NULL;
+	css_file = g_file_new_for_uri ("resource:///org/gnome/gedit/ui/gedit-style.css");
+	provider = gtk_css_provider_new ();
+	if (gtk_css_provider_load_from_file (provider, css_file, &error))
+	{
+		gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+		                                           GTK_STYLE_PROVIDER (provider),
+		                                           GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	}
+	else
+	{
+		g_warning ("Could not load css provider: %s", error->message);
+		g_error_free (error);
+	}
+
 	/*
 	 * We use the default gtksourceview style scheme manager so that plugins
 	 * can obtain it easily without a gedit specific api, but we need to
@@ -596,7 +681,7 @@ get_active_window (GtkApplication *app)
 	{
 		GtkWindow *window = l->data;
 
-		if (is_in_viewport (window, screen, workspace, viewport_x, viewport_y))
+		if (GEDIT_IS_WINDOW (window) && is_in_viewport (window, screen, workspace, viewport_x, viewport_y))
 		{
 			return GEDIT_WINDOW (window);
 		}
@@ -710,33 +795,6 @@ get_option_context (void)
 	return context;
 }
 
-static gboolean
-option_context_parse (GOptionContext  *context,
-                      gchar          **arguments,
-                      GError         **error)
-{
-	gint argc;
-	gchar **argv;
-	gint i;
-	gboolean ret;
-
-	/* We have to make an extra copy of the array, since g_option_context_parse()
-	 * assumes that it can remove strings from the array without freeing them.
-	 */
-	argc = g_strv_length (arguments);
-	argv = g_new (gchar *, argc);
-	for (i = 0; i < argc; i++)
-	{
-		argv[i] = arguments[i];
-	}
-
-	ret = g_option_context_parse (context, &argc, &argv, error);
-
-	g_free (argv);
-
-	return ret;
-}
-
 static void
 clear_options (void)
 {
@@ -803,7 +861,7 @@ gedit_app_command_line (GApplication            *application,
 	/* Avoid exit() on the main instance */
 	g_option_context_set_help_enabled (context, FALSE);
 
-	if (!option_context_parse (context, arguments, &error))
+	if (!g_option_context_parse_strv (context, &arguments, &error))
 	{
 		/* We should never get here since parsing would have
 		 * failed on the client side... */
@@ -896,7 +954,7 @@ gedit_app_local_command_line (GApplication   *application,
 	/* Handle some of the option without contacting the main instance */
 	context = get_option_context ();
 
-	if (!option_context_parse (context, *arguments, &error))
+	if (!g_option_context_parse_strv (context, arguments, &error))
 	{
 		g_printerr (_("%s\nRun '%s --help' to see a full list of available command line options.\n"),
 		           error->message, (*arguments)[0]);
@@ -905,6 +963,13 @@ gedit_app_local_command_line (GApplication   *application,
 		*exit_status = 1;
 		ret = TRUE;
 	}
+	else if (gapplication_service)
+	{
+		GApplicationFlags old_flags;
+
+		old_flags = g_application_get_flags (application);
+		g_application_set_flags (application, old_flags | G_APPLICATION_IS_SERVICE);
+	}
 	else if (version)
 	{
 		g_print ("%s - Version %s\n", g_get_application_name (), VERSION);
@@ -1120,7 +1185,7 @@ window_delete_event (GeditWindow *window,
 		return TRUE;
 	}
 
-	_gedit_cmd_file_quit (NULL, window);
+	_gedit_cmd_file_quit (NULL, NULL, window);
 
 	/* Do not destroy the window */
 	return TRUE;
