@@ -64,9 +64,12 @@ static void tab_state_changed_while_saving (GeditTab    *tab,
 					    GeditWindow *window);
 
 void
-_gedit_cmd_file_new (GtkAction   *action,
-		     GeditWindow *window)
+_gedit_cmd_file_new (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	gedit_window_create_tab (window, TRUE);
@@ -417,9 +420,11 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 }
 
 void
-_gedit_cmd_file_open (GtkAction   *action,
-		      GeditWindow *window)
+_gedit_cmd_file_open (GSimpleAction *action,
+                      GVariant      *parameter,
+                      gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GtkWidget *open_dialog;
 	gpointer data;
 	GeditDocument *doc;
@@ -961,9 +966,11 @@ _gedit_cmd_file_save_tab (GeditTab    *tab,
 }
 
 void
-_gedit_cmd_file_save (GtkAction   *action,
-                      GeditWindow *window)
+_gedit_cmd_file_save (GSimpleAction *action,
+                      GVariant      *parameter,
+                      gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -976,9 +983,11 @@ _gedit_cmd_file_save (GtkAction   *action,
 }
 
 void
-_gedit_cmd_file_save_as (GtkAction   *action,
-                         GeditWindow *window)
+_gedit_cmd_file_save_as (GSimpleAction *action,
+                         GVariant      *parameter,
+                         gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -990,20 +999,6 @@ _gedit_cmd_file_save_as (GtkAction   *action,
 	_gedit_cmd_file_save_as_tab (tab, window);
 }
 
-static gboolean
-document_needs_saving (GeditDocument *doc)
-{
-	if (gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)))
-		return TRUE;
-
-	/* we check if it was deleted only for local files
-	 * since for remote files it may hang */
-	if (gedit_document_is_local (doc) && gedit_document_get_deleted (doc))
-		return TRUE;
-
-	return FALSE;
-}
-
 /*
  * The docs in the list must belong to the same GeditWindow.
  */
@@ -1040,20 +1035,20 @@ _gedit_cmd_file_save_documents_list (GeditWindow *window,
 		    (state == GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW) ||
 		    (state == GEDIT_TAB_STATE_GENERIC_NOT_EDITABLE))
 		{
-			/* FIXME: manage the case of local readonly files owned by the
-			   user is running gedit - Paolo (Dec. 8, 2005) */
-			if (gedit_document_is_untitled (doc) ||
-			    gedit_document_get_readonly (doc))
+			if (_gedit_document_needs_saving (doc))
 			{
-				if (document_needs_saving (doc))
-			     	{
-				     	tabs_to_save_as = g_slist_prepend (tabs_to_save_as,
+				/* FIXME: manage the case of local readonly files owned by the
+				   user is running gedit - Paolo (Dec. 8, 2005) */
+				if (gedit_document_is_untitled (doc) ||
+				    gedit_document_get_readonly (doc))
+				{
+					tabs_to_save_as = g_slist_prepend (tabs_to_save_as,
 									   t);
-			     	}
-			}
-			else
-			{
-				_gedit_cmd_file_save_tab (t, window);
+				}
+				else
+				{
+					_gedit_cmd_file_save_tab (t, window);
+				}
 			}
 		}
 		else
@@ -1129,10 +1124,11 @@ gedit_commands_save_all_documents (GeditWindow *window)
 }
 
 void
-_gedit_cmd_file_save_all (GtkAction   *action,
-			  GeditWindow *window)
+_gedit_cmd_file_save_all (GSimpleAction *action,
+                          GVariant      *parameter,
+                          gpointer       user_data)
 {
-	gedit_commands_save_all_documents (window);
+	gedit_commands_save_all_documents (GEDIT_WINDOW (user_data));
 }
 
 void
@@ -1317,9 +1313,11 @@ revert_dialog (GeditWindow   *window,
 }
 
 void
-_gedit_cmd_file_revert (GtkAction   *action,
-		        GeditWindow *window)
+_gedit_cmd_file_revert (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
 {
+	GeditWindow    *window = GEDIT_WINDOW (user_data);
 	GeditTab       *tab;
 	GeditDocument  *doc;
 	GtkWidget      *dialog;
@@ -1420,7 +1418,7 @@ tab_state_changed_while_saving (GeditTab    *tab,
 
 		/* If the saving operation failed or was interrupted, then the
 		   document is still "modified" -> do not close the tab */
-		if (document_needs_saving (doc))
+		if (_gedit_document_needs_saving (doc))
 			return;
 
 		/* Close the document only if it has been succesfully saved.
@@ -1542,7 +1540,7 @@ save_and_close_all_documents (const GList  *docs,
 			    (state != GEDIT_TAB_STATE_REVERTING)) /* CHECK: is this the right behavior with REVERTING ?*/
 			{
 				/* The document must be saved before closing */
-				g_return_if_fail (document_needs_saving (doc));
+				g_return_if_fail (_gedit_document_needs_saving (doc));
 
 				/* FIXME: manage the case of local readonly files owned by the
 				   user is running gedit - Paolo (Dec. 8, 2005) */
@@ -1816,9 +1814,11 @@ _gedit_cmd_file_close_tab (GeditTab    *tab,
 }
 
 void
-_gedit_cmd_file_close (GtkAction   *action,
-		       GeditWindow *window)
+_gedit_cmd_file_close (GSimpleAction *action,
+                       GVariant      *parameter,
+                       gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *active_tab;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -1906,9 +1906,12 @@ file_close_all (GeditWindow *window,
 }
 
 void
-_gedit_cmd_file_close_all (GtkAction   *action,
-			   GeditWindow *window)
+_gedit_cmd_file_close_all (GSimpleAction *action,
+                           GVariant      *parameter,
+                           gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	g_return_if_fail (!(gedit_window_get_state (window) &
@@ -1949,9 +1952,12 @@ quit_all (void)
 }
 
 void
-_gedit_cmd_file_quit (GtkAction   *action,
-                      GeditWindow *window)
+_gedit_cmd_file_quit (GSimpleAction *action,
+                      GVariant      *parameter,
+                      gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	if (window == NULL)
