@@ -563,9 +563,11 @@ create_dialog (GeditWindow *window)
 }
 
 void
-_gedit_cmd_search_find (GtkAction   *action,
-			GeditWindow *window)
+_gedit_cmd_search_find (GSimpleAction *action,
+                        GVariant      *parameter,
+                        gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *active_tab;
 	GeditViewFrame *frame;
 
@@ -583,9 +585,11 @@ _gedit_cmd_search_find (GtkAction   *action,
 }
 
 void
-_gedit_cmd_search_replace (GtkAction   *action,
-			   GeditWindow *window)
+_gedit_cmd_search_replace (GSimpleAction *action,
+                           GVariant      *parameter,
+                           gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	gpointer data;
 	GtkWidget *replace_dialog;
 
@@ -611,27 +615,35 @@ _gedit_cmd_search_replace (GtkAction   *action,
 }
 
 void
-_gedit_cmd_search_find_next (GtkAction   *action,
-			     GeditWindow *window)
+_gedit_cmd_search_find_next (GSimpleAction *action,
+                             GVariant      *parameter,
+                             gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	run_forward_search (window, FALSE);
 }
 
 void
-_gedit_cmd_search_find_prev (GtkAction   *action,
-			     GeditWindow *window)
+_gedit_cmd_search_find_prev (GSimpleAction *action,
+                             GVariant      *parameter,
+                             gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	run_backward_search (window, FALSE);
 }
 
 void
-_gedit_cmd_search_clear_highlight (GtkAction   *action,
-				   GeditWindow *window)
+_gedit_cmd_search_clear_highlight (GSimpleAction *action,
+                                   GVariant      *parameter,
+                                   gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *active_tab;
 	GeditViewFrame *frame;
 	GeditDocument *doc;
@@ -653,9 +665,11 @@ _gedit_cmd_search_clear_highlight (GtkAction   *action,
 }
 
 void
-_gedit_cmd_search_goto_line (GtkAction   *action,
-			     GeditWindow *window)
+_gedit_cmd_search_goto_line (GSimpleAction *action,
+                             GVariant      *parameter,
+                             gpointer       user_data)
 {
+	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *active_tab;
 	GeditViewFrame *frame;
 
