@@ -20,6 +20,7 @@
 
 
 #include "gedit-notebook-popup-menu.h"
+#include "gedit-multi-notebook.h"
 #include "gedit-commands.h"
 #include <glib/gi18n.h>
 
@@ -27,6 +28,12 @@ struct _GeditNotebookPopupMenuPrivate
 {
 	GeditWindow *window;
 	GeditTab *tab;
+
+	GtkWidget *move_left_item;
+	GtkWidget *move_right_item;
+	GtkWidget *move_to_new_tab_group_item;
+	GtkWidget *move_to_new_window_item;
+	GtkWidget *close_item;
 };
 
 enum
@@ -92,6 +99,51 @@ gedit_notebook_popup_menu_finalize (GObject *object)
 	G_OBJECT_CLASS (gedit_notebook_popup_menu_parent_class)->finalize (object);
 }
 
+static void
+update_sensitivity (GeditNotebookPopupMenu *menu)
+{
+	GeditTabState state;
+	GeditMultiNotebook *mnb;
+	GtkNotebook *notebook;
+	gint page_num;
+	gint n_pages;
+	guint n_tabs;
+
+	state = gedit_tab_get_state (menu->priv->tab);
+
+	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->priv->window));
+
+	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->priv->tab));
+	n_pages = gtk_notebook_get_n_pages (notebook);
+	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->priv->tab));
+
+	gtk_widget_set_sensitive (menu->priv->close_item,
+				  (state != GEDIT_TAB_STATE_CLOSING) &&
+				  (state != GEDIT_TAB_STATE_SAVING) &&
+				  (state != GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW) &&
+				  (state != GEDIT_TAB_STATE_PRINTING) &&
+				  (state != GEDIT_TAB_STATE_PRINT_PREVIEWING) &&
+				  (state != GEDIT_TAB_STATE_SAVING_ERROR));
+
+	gtk_widget_set_sensitive (menu->priv->move_to_new_tab_group_item, n_pages > 1);
+
+	n_tabs = gedit_multi_notebook_get_n_tabs(mnb);
+	gtk_widget_set_sensitive (menu->priv->move_to_new_window_item, n_tabs > 1);
+
+	gtk_widget_set_sensitive (menu->priv->move_left_item, page_num > 0);
+	gtk_widget_set_sensitive (menu->priv->move_right_item, page_num < n_pages - 1);
+}
+
+static void
+gedit_notebook_popup_menu_constructed (GObject *object)
+{
+	GeditNotebookPopupMenu *menu = GEDIT_NOTEBOOK_POPUP_MENU (object);
+
+	update_sensitivity (menu);
+
+	G_OBJECT_CLASS (gedit_notebook_popup_menu_parent_class)->constructed (object);
+}
+
 static void
 gedit_notebook_popup_menu_class_init (GeditNotebookPopupMenuClass *klass)
 {
@@ -99,6 +151,7 @@ gedit_notebook_popup_menu_class_init (GeditNotebookPopupMenuClass *klass)
 
 	object_class->get_property = gedit_notebook_popup_menu_get_property;
 	object_class->set_property = gedit_notebook_popup_menu_set_property;
+	object_class->constructed = gedit_notebook_popup_menu_constructed;
 	object_class->finalize = gedit_notebook_popup_menu_finalize;
 
 	g_object_class_install_property (object_class,
@@ -121,11 +174,10 @@ gedit_notebook_popup_menu_class_init (GeditNotebookPopupMenuClass *klass)
 }
 
 static void
-on_move_to_new_window_menuitem_activate (GtkMenuItem            *menuitem,
-                                         GeditNotebookPopupMenu *menu)
+on_file_close_menuitem_activate (GtkMenuItem            *menuitem,
+                                 GeditNotebookPopupMenu *menu)
 {
-	_gedit_window_move_tab_to_new_window (menu->priv->window,
-	                                      menu->priv->tab);
+	_gedit_cmd_file_close_tab (menu->priv->tab, menu->priv->window);
 }
 
 static void
@@ -137,31 +189,53 @@ on_move_to_new_tab_group_menuitem_activate (GtkMenuItem            *menuitem,
 }
 
 static void
-on_file_save_menuitem_activate (GtkMenuItem            *menuitem,
+on_move_to_new_window_menuitem_activate (GtkMenuItem            *menuitem,
+                                         GeditNotebookPopupMenu *menu)
+{
+	_gedit_window_move_tab_to_new_window (menu->priv->window,
+	                                      menu->priv->tab);
+}
+
+static void
+on_move_right_menuitem_activate (GtkMenuItem            *menuitem,
+                                 GeditNotebookPopupMenu *menu)
+{
+	GeditMultiNotebook *mnb;
+	GtkNotebook *notebook;
+	gint page_num;
+	gint n_pages;
+
+	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->priv->window));
+
+	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->priv->tab));
+	n_pages = gtk_notebook_get_n_pages (notebook);
+	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->priv->tab));
+
+	if (page_num <  (n_pages - 1))
+	{
+		gtk_notebook_reorder_child (notebook, GTK_WIDGET (menu->priv->tab),
+		                            page_num + 1);
+	}
+}
+
+static void
+on_move_left_menuitem_activate (GtkMenuItem            *menuitem,
                                 GeditNotebookPopupMenu *menu)
 {
-	_gedit_cmd_file_save_tab (menu->priv->tab, menu->priv->window);
-}
+	GeditMultiNotebook *mnb;
+	GtkNotebook *notebook;
+	gint page_num;
 
-static void
-on_file_save_as_menuitem_activate (GtkMenuItem            *menuitem,
-                                   GeditNotebookPopupMenu *menu)
-{
-	_gedit_cmd_file_save_as_tab (menu->priv->tab, menu->priv->window);
-}
+	mnb = GEDIT_MULTI_NOTEBOOK (_gedit_window_get_multi_notebook (menu->priv->window));
 
-static void
-on_file_print_menuitem_activate (GtkMenuItem            *menuitem,
-                                 GeditNotebookPopupMenu *menu)
-{
-	_gedit_tab_print (menu->priv->tab);
-}
+	notebook = GTK_NOTEBOOK (gedit_multi_notebook_get_notebook_for_tab (mnb, menu->priv->tab));
+	page_num = gtk_notebook_page_num (notebook, GTK_WIDGET (menu->priv->tab));
 
-static void
-on_file_close_menuitem_activate (GtkMenuItem            *menuitem,
-                                 GeditNotebookPopupMenu *menu)
-{
-	_gedit_cmd_file_close_tab (menu->priv->tab, menu->priv->window);
+	if (page_num > 0)
+	{
+		gtk_notebook_reorder_child (notebook, GTK_WIDGET (menu->priv->tab),
+		                            page_num - 1);
+	}
 }
 
 static void
@@ -172,12 +246,17 @@ gedit_notebook_popup_menu_init (GeditNotebookPopupMenu *menu)
 	menu->priv = gedit_notebook_popup_menu_get_instance_private (menu);
 
 	/* Keep in sync with the respective GtkActions */
-	menu_item = gtk_menu_item_new_with_mnemonic (_("_Move to New Window"));
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Close"));
 	g_signal_connect (menu_item, "activate",
-	                  G_CALLBACK (on_move_to_new_window_menuitem_activate),
+	                  G_CALLBACK (on_file_close_menuitem_activate),
 	                  menu);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
+	menu->priv->close_item = menu_item;
+
+	menu_item = gtk_separator_menu_item_new ();
+	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
+	gtk_widget_show (menu_item);
 
 	menu_item = gtk_menu_item_new_with_mnemonic (_("_Move to New Tab Group"));
 	g_signal_connect (menu_item, "activate",
@@ -185,46 +264,35 @@ gedit_notebook_popup_menu_init (GeditNotebookPopupMenu *menu)
 	                  menu);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
+	menu->priv->move_to_new_tab_group_item = menu_item;
+
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Move to New Window"));
+	g_signal_connect (menu_item, "activate",
+	                  G_CALLBACK (on_move_to_new_window_menuitem_activate),
+	                  menu);
+	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
+	gtk_widget_show (menu_item);
+	menu->priv->move_to_new_window_item = menu_item;
 
 	menu_item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
 
-	menu_item = gtk_menu_item_new_with_mnemonic (_("_Save"));
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Move Right"));
 	g_signal_connect (menu_item, "activate",
-	                  G_CALLBACK (on_file_save_menuitem_activate),
+	                  G_CALLBACK (on_move_right_menuitem_activate),
 	                  menu);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
+	menu->priv->move_right_item = menu_item;
 
-	menu_item = gtk_menu_item_new_with_mnemonic (_("Save _As..."));
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Move Left"));
 	g_signal_connect (menu_item, "activate",
-	                  G_CALLBACK (on_file_save_as_menuitem_activate),
-	                  menu);
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
-	gtk_widget_show (menu_item);
-
-	menu_item = gtk_separator_menu_item_new ();
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
-	gtk_widget_show (menu_item);
-
-	menu_item = gtk_menu_item_new_with_mnemonic (_("_Print..."));
-	g_signal_connect (menu_item, "activate",
-	                  G_CALLBACK (on_file_print_menuitem_activate),
-	                  menu);
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
-	gtk_widget_show (menu_item);
-
-	menu_item = gtk_separator_menu_item_new ();
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
-	gtk_widget_show (menu_item);
-
-	menu_item = gtk_menu_item_new_with_mnemonic (_("_Close"));
-	g_signal_connect (menu_item, "activate",
-	                  G_CALLBACK (on_file_close_menuitem_activate),
+	                  G_CALLBACK (on_move_left_menuitem_activate),
 	                  menu);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
 	gtk_widget_show (menu_item);
+	menu->priv->move_left_item = menu_item;
 }
 
 GtkWidget *
