@@ -20,12 +20,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * Modified by the gedit Team, 2005. See the AUTHORS file for a
- * list of people on the gedit Team.
- * See the ChangeLog files for a list of changes.
- */
-
 /* This file is a modified version of the epiphany file ephy-notebook.c
  * Here the relevant copyright:
  *
@@ -79,14 +73,29 @@ enum
 {
 	TAB_CLOSE_REQUEST,
 	SHOW_POPUP_MENU,
+	CHANGE_TO_PAGE,
 	LAST_SIGNAL
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
+static void update_tabs_visibility (GeditNotebook *notebook);
+
 static void
-update_tabs_visibility (GeditNotebook *notebook,
-			gboolean       before_inserting)
+show_tabs_changed (GObject     *object,
+		   GParamSpec  *pspec,
+		   gpointer    *data)
+{
+	GeditNotebook *notebook = GEDIT_NOTEBOOK (object);
+
+	if (gtk_notebook_get_show_tabs (GTK_NOTEBOOK (notebook)))
+	{
+		update_tabs_visibility (notebook);
+	}
+}
+
+static void
+update_tabs_visibility (GeditNotebook *notebook)
 {
 	gboolean show_tabs;
 
@@ -96,16 +105,7 @@ update_tabs_visibility (GeditNotebook *notebook,
 			show_tabs = FALSE;
 			break;
 		case GEDIT_NOTEBOOK_SHOW_TABS_AUTO:
-			{
-				guint num;
-
-				num = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
-
-				if (before_inserting)
-					++num;
-
-				show_tabs = num > 1;
-			}
+			show_tabs = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) > 1;
 			break;
 		case GEDIT_NOTEBOOK_SHOW_TABS_ALWAYS:
 		default:
@@ -113,7 +113,9 @@ update_tabs_visibility (GeditNotebook *notebook,
 			break;
 	}
 
+	g_signal_handlers_block_by_func (notebook, show_tabs_changed, NULL);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook), show_tabs);
+	g_signal_handlers_unblock_by_func (notebook, show_tabs_changed, NULL);
 }
 
 static void
@@ -148,7 +150,7 @@ gedit_notebook_set_property (GObject      *object,
 	{
 		case PROP_SHOW_TABS_MODE:
 			notebook->priv->show_tabs_mode = g_value_get_enum (value);
-			update_tabs_visibility (notebook, FALSE);
+			update_tabs_visibility (notebook);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -396,7 +398,6 @@ gedit_notebook_page_removed (GtkNotebook *notebook,
                              guint        page_num)
 {
 	GeditNotebook *nb = GEDIT_NOTEBOOK (notebook);
-	gint num_pages;
 	gint curr;
 	GtkWidget *tab_label;
 
@@ -423,13 +424,7 @@ gedit_notebook_page_removed (GtkNotebook *notebook,
 		smart_tab_switching_on_closure (nb, GEDIT_TAB (page));
 	}
 
-	num_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (nb));
-
-	/* If there is no tabs, calling this is pointless */
-	if (num_pages > 0)
-	{
-		update_tabs_visibility (nb, FALSE);
-	}
+	update_tabs_visibility (nb);
 }
 
 static void
@@ -452,7 +447,7 @@ gedit_notebook_page_added (GtkNotebook *notebook,
 	                  G_CALLBACK (close_button_clicked_cb),
 	                  nb);
 
-	update_tabs_visibility (GEDIT_NOTEBOOK (notebook), FALSE);
+	update_tabs_visibility (GEDIT_NOTEBOOK (notebook));
 }
 
 static void
@@ -475,6 +470,25 @@ gedit_notebook_remove (GtkContainer *container,
 	nb->priv->ignore_focused_page_update = FALSE;
 }
 
+static gboolean
+gedit_notebook_change_to_page (GeditNotebook *notebook,
+                               gint           page_num)
+{
+	gint n_pages;
+
+	n_pages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook));
+
+	if (page_num > n_pages - 1)
+	{
+		return FALSE;
+	}
+
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook),
+	                               page_num);
+
+	return TRUE;
+}
+
 static void
 gedit_notebook_class_init (GeditNotebookClass *klass)
 {
@@ -482,6 +496,8 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 	GtkWidgetClass *gtkwidget_class = GTK_WIDGET_CLASS (klass);
 	GtkNotebookClass *notebook_class = GTK_NOTEBOOK_CLASS (klass);
 	GtkContainerClass *container_class = GTK_CONTAINER_CLASS (klass);
+	GtkBindingSet *binding_set;
+	gint i;
 
 	object_class->dispose = gedit_notebook_dispose;
 	object_class->finalize = gedit_notebook_finalize;
@@ -498,6 +514,8 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 
 	container_class->remove = gedit_notebook_remove;
 
+	klass->change_to_page = gedit_notebook_change_to_page;
+
 	g_object_class_install_property (object_class, PROP_SHOW_TABS_MODE,
 					 g_param_spec_enum ("show-tabs-mode",
 							    "Show Tabs Mode",
@@ -528,6 +546,24 @@ gedit_notebook_class_init (GeditNotebookClass *klass)
 			      2,
 			      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
 			      GEDIT_TYPE_TAB);
+	signals[CHANGE_TO_PAGE] =
+		g_signal_new ("change-to-page",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+		              G_STRUCT_OFFSET (GeditNotebookClass, change_to_page),
+		              NULL, NULL,
+		              gedit_marshal_BOOLEAN__INT,
+		              G_TYPE_BOOLEAN, 1,
+		              G_TYPE_INT);
+
+	binding_set = gtk_binding_set_by_class (klass);
+	for (i = 1; i < 10; i++)
+	{
+		gtk_binding_entry_add_signal (binding_set,
+		                              GDK_KEY_0 + i, GDK_MOD1_MASK,
+		                              "change-to-page", 1,
+		                              G_TYPE_INT, i - 1);
+	}
 }
 
 /**
@@ -554,6 +590,7 @@ gedit_notebook_init (GeditNotebook *notebook)
 	priv->ui_settings = g_settings_new ("org.gnome.gedit.preferences.ui");
 
 	priv->show_tabs_mode = GEDIT_NOTEBOOK_SHOW_TABS_ALWAYS;
+
 	priv->close_buttons_sensitive = TRUE;
 
 	gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
@@ -568,6 +605,11 @@ gedit_notebook_init (GeditNotebook *notebook)
 			 notebook,
 			 "show-tabs-mode",
 			 G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+
+	g_signal_connect (notebook,
+			  "notify::show-tabs",
+			  G_CALLBACK (show_tabs_changed),
+			  NULL);
 }
 
 static GtkWidget *
