@@ -82,7 +82,7 @@ struct _GeditPrintPreviewPrivate
 	guint cur_page;
 };
 
-G_DEFINE_TYPE (GeditPrintPreview, gedit_print_preview, GTK_TYPE_GRID)
+G_DEFINE_TYPE_WITH_PRIVATE (GeditPrintPreview, gedit_print_preview, GTK_TYPE_GRID)
 
 static void
 gedit_print_preview_get_property (GObject    *object,
@@ -152,19 +152,17 @@ gedit_print_preview_class_init (GeditPrintPreviewClass *klass)
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-print-preview.ui");
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, prev);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, next);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, multi);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, page_entry);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, last);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, zoom_one);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, zoom_fit);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, zoom_in);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, zoom_out);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, close);
-	gtk_widget_class_bind_child (widget_class, GeditPrintPreviewPrivate, layout);
-
-	g_type_class_add_private (object_class, sizeof (GeditPrintPreviewPrivate));
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, prev);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, next);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, multi);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, page_entry);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, last);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, zoom_one);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, zoom_fit);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, zoom_in);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, zoom_out);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, close);
+	gtk_widget_class_bind_template_child_private (widget_class, GeditPrintPreview, layout);
 }
 
 static void
@@ -790,10 +788,7 @@ gedit_print_preview_init (GeditPrintPreview *preview)
 {
 	GeditPrintPreviewPrivate *priv;
 
-	priv = G_TYPE_INSTANCE_GET_PRIVATE (preview,
-					    GEDIT_TYPE_PRINT_PREVIEW,
-					    GeditPrintPreviewPrivate);
-
+	priv = gedit_print_preview_get_instance_private (preview);
 	preview->priv = priv;
 
 	priv->operation = NULL;
