@@ -55,8 +55,8 @@ struct _GeditTabPrivate
 
 	GeditViewFrame         *frame;
 
-	GtkWidget	       *info_bar_revealer;
 	GtkWidget	       *info_bar;
+	GtkWidget	       *info_bar_hidden;
 	GtkWidget	       *print_preview;
 
 	GeditPrintJob          *print_job;
@@ -525,43 +525,47 @@ static void
 set_info_bar (GeditTab  *tab,
 	      GtkWidget *info_bar)
 {
+	gedit_debug (DEBUG_TAB);
+
 	if (tab->priv->info_bar == info_bar)
 		return;
 
-	tab->priv->info_bar = info_bar;
-
 	if (info_bar == NULL)
 	{
-		gtk_revealer_set_reveal_child (GTK_REVEALER (tab->priv->info_bar_revealer), FALSE);
-		tab->priv->info_bar = NULL;
+		if (tab->priv->info_bar != NULL)
+		{
+			/* Don't destroy the old info_bar right away,
+			   we want the hide animation. */
+			if (tab->priv->info_bar_hidden != NULL)
+			{
+				gtk_widget_destroy (tab->priv->info_bar_hidden);
+			}
+
+			tab->priv->info_bar_hidden = tab->priv->info_bar;
+			gtk_widget_hide (tab->priv->info_bar_hidden);
+
+			tab->priv->info_bar = NULL;
+		}
 	}
 	else
 	{
-		/* lazy init the reveler */
-		if (tab->priv->info_bar_revealer == NULL)
+		if (tab->priv->info_bar != NULL)
 		{
-			tab->priv->info_bar_revealer = gtk_revealer_new ();
-			gtk_widget_show (tab->priv->info_bar_revealer);
-			gtk_box_pack_start (GTK_BOX (tab), tab->priv->info_bar_revealer, FALSE, FALSE, 0);
-		}
-		else
-		{
-			GtkWidget *old;
-
-			old = gtk_bin_get_child (GTK_BIN (tab->priv->info_bar_revealer));
-			if (old != NULL)
-			{
-				g_object_remove_weak_pointer (G_OBJECT (old),
-				                              (gpointer *)&tab->priv->info_bar);
-				gtk_container_remove (GTK_CONTAINER (tab->priv->info_bar_revealer), old);
-			}
+			gedit_debug_message (DEBUG_TAB, "Replacing existing notification");
+			gtk_widget_destroy (tab->priv->info_bar);
 		}
 
-		gtk_container_add (GTK_CONTAINER (tab->priv->info_bar_revealer), info_bar);
-		gtk_revealer_set_reveal_child (GTK_REVEALER (tab->priv->info_bar_revealer), TRUE);
+		/* Make sure to stop a possibly still ongoing hiding animation. */
+		if (tab->priv->info_bar_hidden != NULL)
+		{
+			gtk_widget_destroy (tab->priv->info_bar_hidden);
+			tab->priv->info_bar_hidden = NULL;
+		}
 
-		g_object_add_weak_pointer (G_OBJECT (info_bar),
-					   (gpointer *)&tab->priv->info_bar);
+		tab->priv->info_bar = info_bar;
+
+		gtk_box_pack_start (GTK_BOX (tab), info_bar, FALSE, FALSE, 0);
+		gtk_widget_show (info_bar);
 	}
 }
 
@@ -657,7 +661,7 @@ file_already_open_warning_info_bar_response (GtkWidget   *info_bar,
 					    TRUE);
 	}
 
-	gtk_widget_destroy (info_bar);
+	set_info_bar (tab, NULL);
 
 	gtk_widget_grab_focus (GTK_WIDGET (view));
 }
@@ -807,8 +811,6 @@ show_loading_info_bar (GeditTab *tab)
 			  G_CALLBACK (load_cancelled),
 			  tab);
 
-	gtk_widget_show (bar);
-
 	set_info_bar (tab, bar);
 
 	g_free (msg);
@@ -888,8 +890,6 @@ show_saving_info_bar (GeditTab *tab)
 					   msg,
 					   FALSE);
 
-	gtk_widget_show (bar);
-
 	set_info_bar (tab, bar);
 
 	g_free (msg);
@@ -1054,14 +1054,11 @@ document_loaded (GeditDocument *document,
 						  tab);
 			}
 
+			gtk_info_bar_set_default_response (GTK_INFO_BAR (emsg),
+							   GTK_RESPONSE_CANCEL);
 			set_info_bar (tab, emsg);
 		}
 
-		gtk_info_bar_set_default_response (GTK_INFO_BAR (emsg),
-						   GTK_RESPONSE_CANCEL);
-
-		gtk_widget_show (emsg);
-
 		if (location)
 		{
 			g_object_unref (location);
@@ -1096,8 +1093,6 @@ document_loaded (GeditDocument *document,
 								    tab->priv->tmp_encoding,
 								    error);
 
-			set_info_bar (tab, emsg);
-
 			g_signal_connect (emsg,
 					  "response",
 					  G_CALLBACK (io_loading_error_info_bar_response),
@@ -1106,7 +1101,7 @@ document_loaded (GeditDocument *document,
 			gtk_info_bar_set_default_response (GTK_INFO_BAR (emsg),
 							   GTK_RESPONSE_CANCEL);
 
-			gtk_widget_show (emsg);
+			set_info_bar (tab, emsg);
 		}
 
 		/* Scroll to the cursor when the document is loaded, we need
@@ -1142,18 +1137,17 @@ document_loaded (GeditDocument *document,
 
 						w = gedit_file_already_open_warning_info_bar_new (location);
 
-						set_info_bar (tab, w);
 
 						gtk_info_bar_set_default_response (GTK_INFO_BAR (w),
 										   GTK_RESPONSE_CANCEL);
 
-						gtk_widget_show (w);
-
 						g_signal_connect (w,
 								  "response",
 								  G_CALLBACK (file_already_open_warning_info_bar_response),
 								  tab);
 
+						set_info_bar (tab, w);
+
 						g_object_unref (loc);
 						break;
 					}
@@ -1285,6 +1279,10 @@ invalid_character_info_bar_response (GtkWidget *info_bar,
 		g_return_if_fail (tab->priv->auto_save_timeout <= 0);
 
 		/* Force saving */
+
+		/* FIXME there is a bug here when the action was a "save as".
+		 * See https://bugzilla.gnome.org/show_bug.cgi?id=695107
+		 */
 		gedit_document_save (doc, tab->priv->save_flags);
 	}
 	else
@@ -1314,9 +1312,6 @@ no_backup_error_info_bar_response (GtkWidget *info_bar,
 
 		gedit_tab_set_state (tab, GEDIT_TAB_STATE_SAVING);
 
-		/* don't bug the user again with this... */
-		tab->priv->save_flags |= GEDIT_DOCUMENT_SAVE_IGNORE_BACKUP;
-
 		g_return_if_fail (tab->priv->auto_save_timeout <= 0);
 
 		/* Force saving */
@@ -1448,8 +1443,6 @@ document_saved (GeditDocument *document,
 							error);
 			g_return_if_fail (emsg != NULL);
 
-			set_info_bar (tab, emsg);
-
 			g_signal_connect (emsg,
 					  "response",
 					  G_CALLBACK (externally_modified_error_info_bar_response),
@@ -1466,8 +1459,6 @@ document_saved (GeditDocument *document,
 							error);
 			g_return_if_fail (emsg != NULL);
 
-			set_info_bar (tab, emsg);
-
 			g_signal_connect (emsg,
 					  "response",
 					  G_CALLBACK (no_backup_error_info_bar_response),
@@ -1481,8 +1472,6 @@ document_saved (GeditDocument *document,
 			emsg = gedit_invalid_character_info_bar_new (tab->priv->tmp_save_location);
 			g_return_if_fail (emsg != NULL);
 
-			set_info_bar (tab, emsg);
-
 			g_signal_connect (emsg,
 			                  "response",
 			                  G_CALLBACK (invalid_character_info_bar_response),
@@ -1501,8 +1490,6 @@ document_saved (GeditDocument *document,
 								  error);
 			g_return_if_fail (emsg != NULL);
 
-			set_info_bar (tab, emsg);
-
 			g_signal_connect (emsg,
 					  "response",
 					  G_CALLBACK (unrecoverable_saving_error_info_bar_response),
@@ -1518,8 +1505,7 @@ document_saved (GeditDocument *document,
 									tab->priv->tmp_save_location,
 									tab->priv->tmp_encoding,
 									error);
-
-			set_info_bar (tab, emsg);
+			g_return_if_fail (emsg != NULL);
 
 			g_signal_connect (emsg,
 					  "response",
@@ -1530,7 +1516,7 @@ document_saved (GeditDocument *document,
 		gtk_info_bar_set_default_response (GTK_INFO_BAR (emsg),
 						   GTK_RESPONSE_CANCEL);
 
-		gtk_widget_show (emsg);
+		set_info_bar (tab, emsg);
 	}
 	else
 	{
@@ -1596,9 +1582,7 @@ display_externally_modified_notification (GeditTab *tab)
 	info_bar = gedit_externally_modified_info_bar_new (location, document_modified);
 	g_object_unref (location);
 
-	tab->priv->info_bar = NULL;
 	set_info_bar (tab, info_bar);
-	gtk_widget_show (info_bar);
 
 	g_signal_connect (info_bar,
 			  "response",
@@ -2361,6 +2345,11 @@ get_print_settings (GeditTab *tab)
 		settings = gtk_print_settings_copy (GTK_PRINT_SETTINGS (data));
 	}
 
+	/* Be sure the OUTPUT_URI is unset, because otherwise the
+	 * OUTPUT_BASENAME is not taken into account.
+	 */
+	gtk_print_settings_set (settings, GTK_PRINT_SETTINGS_OUTPUT_URI, NULL);
+
 	name = gedit_document_get_short_name_for_display (doc);
 	gtk_print_settings_set (settings, GTK_PRINT_SETTINGS_OUTPUT_BASENAME, name);
 
@@ -2751,14 +2740,7 @@ _gedit_tab_get_can_close (GeditTab *tab)
 
 	doc = gedit_tab_get_document (tab);
 
-	if (gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)))
-	{
-		return FALSE;
-	}
-
-	if (gedit_document_is_local (doc) &&
-	    (gedit_document_get_deleted (doc) ||
-	    _gedit_document_check_externally_modified (doc)))
+	if (_gedit_document_needs_saving (doc))
 	{
 		return FALSE;
 	}
