@@ -65,6 +65,9 @@ struct _GeditWindowPrivate
 
 	/* Widgets for fullscreen mode */
 	GtkWidget      *fullscreen_controls;
+	GtkWidget      *fullscreen_open_menu;
+	GtkMenuButton  *fullscreen_gear_button;
+	gboolean        fullscreen_controls_setup;
 	guint           fullscreen_animation_timeout_id;
 	gboolean        fullscreen_animation_enter;
 
@@ -72,8 +75,8 @@ struct _GeditWindowPrivate
 	GtkWidget      *statusbar;
 	GtkWidget      *tab_width_combo;
 	GtkWidget      *tab_width_combo_menu;
-	GtkWidget      *language_combo;
-	GtkWidget      *language_combo_menu;
+	GtkWidget      *language_button;
+	GtkWidget      *language_button_label;
 	guint           generic_message_cid;
 	guint           tip_message_cid;
 	guint 	        bracket_match_message_cid;
@@ -81,24 +84,18 @@ struct _GeditWindowPrivate
 	guint 	        tab_width_id;
 	guint 	        language_changed_id;
 
-	/* Menus & Toolbars */
-	GtkUIManager   *manager;
-	GtkActionGroup *action_group;
-	GtkActionGroup *always_sensitive_action_group;
-	GtkActionGroup *close_action_group;
-	GtkActionGroup *quit_action_group;
-	GtkActionGroup *panels_action_group;
-	GtkActionGroup *documents_list_action_group;
-	guint           documents_list_menu_ui_id;
-	GtkWidget      *toolbar;
-	GtkWidget      *menubar;
+	/* Headerbars */
+	GtkWidget      *titlebar_paned;
+	GtkWidget      *side_headerbar;
+	GtkWidget      *headerbar;
+	GtkWidget      *open_button;
+	GtkWidget      *open_menu;
+	GtkMenuButton  *gear_button;
+	GMenuModel     *gear_menu;
+	GMenuModel     *gear_menu_win;
+	GMenuModel     *gear_menu_app;
 
 	/* recent files */
-	GtkActionGroup *recents_action_group;
-	guint           recents_menu_ui_id;
-	gulong          recents_handler_id;
-
-	guint           update_documents_list_menu_id;
 
 	gint            num_tabs_with_error;
 
