@@ -83,6 +83,9 @@ def run_external_tool(window, panel, node):
         
         capture.set_env(GEDIT_CURRENT_LINE=piter.get_text(end))
         
+        if document.get_language() is not None:
+            capture.set_env(GEDIT_CURRRENT_DOCUMENT_LANGUAGE=document.get_language().get_id())
+
         # Selected text (only if input is not selection)
         if node.input != 'selection' and node.input != 'selection-document':
             bounds = document.get_selection_bounds()
@@ -286,7 +289,7 @@ class MultipleDocumentsSaver:
         if self._counter == 0 and not self._error:
             run_external_tool(self._window, self._panel, self._node)
 
-def capture_menu_action(action, window, panel, node):
+def capture_menu_action(action, parameter, window, panel, node):
     if node.save_files == 'document' and window.get_active_document():
         MultipleDocumentsSaver(window, panel, False, node)
         return
