@@ -529,7 +529,7 @@ gedit_file_browser_plugin_activate (GeditWindowActivatable *activatable)
 
 	panel = gedit_window_get_side_panel (priv->window);
 
-	image = gtk_image_new_from_icon_name ("system-file-manager",
+	image = gtk_image_new_from_icon_name ("system-file-manager-symbolic",
 	                                      GTK_ICON_SIZE_MENU);
 	gtk_widget_show (image);
 	gedit_panel_add_item (panel,
